#
# spec file for package deepin-daemon
#
# Copyright (c) 2021 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define   _name       dde-daemon
%define   import_path pkg.deepin.io/dde/daemon

Name:           deepin-daemon
Version:        5.14.11.1
Release:        bp154.1.53
Summary:        Daemon handling the DDE session settings
License:        GPL-3.0+
URL:            https://github.com/linuxdeepin/dde-daemon
Source0:        https://github.com/linuxdeepin/dde-daemon/archive/%{version}/%{_name}-%{version}.tar.gz
Source1:        %{name}.sysusers
Source2:        vendor.tar.gz
Source3:        %{name}-dbus-installer.in
Source4:        %{name}-polkit-installer.in
Source99:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM deepin-daemon-fix-policy-settings.patch
# hillwood@opensuse.org - Fix policy settings.
# Patch0:         %{name}-fix-policy-settings.patch
# PATCH-FIX-OPENSUSE deepin-daemon-libinput.patch.patch hillwood@opensuse.org - Fix build on libinput.
Patch1:         %{name}-libinput.patch
# PATCH-FIX-OPENSUSE disable-gobuild-in-makefile.patch hillwood@opensuse.org
# Use gobuild macro instead of makefile to build go binaries
Patch2:         disable-gobuild-in-makefile.patch
# PATCH-Fix-UPSTREAM fix-login_defs-path.patch
# https://github.com/linuxdeepin/dde-daemon/commit/1262c03c5e5b4771f04a73ee2c01e1490f4e96af
Patch3:         fix-login_defs-path.patch
Patch4:         harden_deepin-accounts-daemon.service.patch
Group:          System/GUI/Other
BuildRequires:  lightdm
BuildRequires:  lightdm-gtk-greeter
BuildRequires:  golang-packaging
BuildRequires:  deepin-gettext-tools
BuildRequires:  fontpackages-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(gdk-pixbuf-xlib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(libbamf3)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libnl-genl-3.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  golang-github-linuxdeepin-go-dbus-factory
BuildRequires:  golang-github-linuxdeepin-dde-api
%if 0%{?sle_version} == 150200
BuildRequires:  golang-github-stretchr-testify
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150200
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif
BuildRequires:  pkgconfig(systemd)
BuildRequires:  systemd-rpm-macros
Requires:       acpid
Requires:       gvfs
Requires:       iw
Requires:       rfkill
Requires:       upower
Requires:       xdotool
Requires:       xvfb-run
Requires:       wallpaper-branding-SLE
%if %{suse_version} > 1500
Requires:       libgdk_pixbuf_xlib-2_0-0
%else
Requires:       libgdk_pixbuf-2_0-0
%endif
Recommends:     %{name}-lang = %{version}
Recommends:     iso-codes
Recommends:     mobile-broadband-provider-info
AutoReqProv:    Off
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_ordering}

%description
Deepin Daemon is a daemon for handling the deepin session settings

%package polkit
Summary:        Deepin daemon polkit profiles
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
AutoReqProv:    Off

%description polkit
This package provides polkit profiles for deepin-daemon. These profiles are not
adopted by security team. If you need the polkit feature, you should install
them manually or use deepin-polkit-install package.

%package dbus
Summary:        Deepin daemon DBus profiles
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
AutoReqProv:    Off

%description dbus
This package provides dbus profiles for deepin-daemon. These profiles are not
adopted by security team. If you need the dbus feature, you should install
them manually or use deepin-dbus-install package.

%package -n golang-github-linuxdeepin-deepin-daemon
Summary:        Deepin daemon golang codes
Group:          Development/Languages/Golang
Requires:       golang-github-linuxdeepin-go-dbus-factory
Requires:       golang-github-linuxdeepin-dde-api
BuildArch:      noarch
AutoReqProv:    On
AutoReq:        Off
%{go_provides}

%description -n golang-github-linuxdeepin-deepin-daemon
This package contains library source intended forbuilding other packages which
use import path with pkg.deepin.io/dde/daemon prefix.

%package lightdm
Summary:        Deepin Desktop branding setting for lightdm
Group:          System/X11/Displaymanagers
Requires:       lightdm
Requires:       %{name} = %{version}
AutoReqProv:    Off

%description lightdm
Deepin Desktop branding setting for lightdm

%package pam
Summary:        Deepin Keyring - PAM module
Group:          System/GUI/Other
Requires:       %{name} = %{version}
PreReq:         pam-config >= 0.72
PreReq:         sed
AutoReqProv:    Off

%description pam
Deepin Daemon is a daemon for handling the deepin session settings

The PAM module can be used to unlock the keyring on login.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
AutoReqProv:    Off

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1 -a2 -n %{_name}-%{version}
%if 0%{?sle_version} == 150200
rm -rf vendor/github.com/stretchr/testify/
%endif
mkdir -p $HOME/rpmbuild/BUILD/go/src/
cp vendor/* $HOME/rpmbuild/BUILD/go/src/ -r
rm -rf vendor

sed -i '/systemd/s|lib|usr/lib|' Makefile
sed -i 's|lib/NetworkManager|lib|' network/utils_test.go

# Fix grub.cfg path and don't change openSUSE default grub2 theme
sed -i 's|boot/grub/deepin|boot/grub2/openSUSE|' grub2/*.go
sed -i 's|/usr/share/backgrounds/default_background.jpg|/usr/share/wallpapers/openSUSEdefault/contents/images/1920x1080.jpg|' accounts/user.go

sed -i 's|/lib/udev|/usr/lib/udev|g' Makefile
sed -i 's|/etc/modules-load.d|/usr/lib/modules-load.d|g' Makefile

sed -i 's|qdbus|qdbus-qt5|g' network/examples/set_wired_static_ip.sh misc/etc/acpi/powerbtn.sh

%build
export GO111MODULE=off
%goprep %{import_path}
%gobuild ...
%make_build

%install
rm -rf $HOME/rpmbuild/BUILD/go/src/github.com \
       $HOME/rpmbuild/BUILD/go/src/golang.org \
       $HOME/rpmbuild/BUILD/go/src/gopkg.in
%goinstall
%gosrc
%make_install
%gofilelist
pushd %{buildroot}%{_prefix}/lib/deepin-daemon
    ln -s ../../bin/* .
%if 0%{?suse_version} > 1500
    mv %{buildroot}%{_libexecdir}/dde-daemon/keybinding .
%else
    mv %{buildroot}%{_prefix}/libexec/dde-daemon/keybinding .
%endif
popd

install -Dm644 %{SOURCE1} %{buildroot}%{_prefix}/lib/sysusers.d/deepin-daemon.conf
install -Dm755 %{SOURCE3} %{buildroot}%{_bindir}/%{name}-dbus-installer
install -Dm755 %{SOURCE4} %{buildroot}%{_bindir}/%{name}-polkit-installer

# fix systemd/logind config
install -d %{buildroot}%{_prefix}/lib/systemd/logind.conf.d/
cat > %{buildroot}%{_prefix}/lib/systemd/logind.conf.d/10-%{name}.conf <<EOF
[Login]
HandlePowerKey=ignore
HandleSuspendKey=ignore
EOF

install -d %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcdeepin-accounts-daemon
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rchwclock_stop

# File all polkit profiles, workaround boo#1070943
mkdir build
pushd build
mkdir polkit
mv %{buildroot}%{_datadir}/polkit-1/actions/* polkit/
tar -cvf polkit.tar.gz polkit
install -m 0644 polkit.tar.gz %{buildroot}%{_datadir}/dde-daemon/

# File all dbus service profiles, workaround boo#1070943
mkdir dbus
mkdir dbus/system-services
mkdir dbus/system.d
mv %{buildroot}%{_datadir}/dbus-1/system-services/* dbus/system-services
mv %{buildroot}%{_datadir}/dbus-1/system.d/* dbus/system.d
tar -cvf dbus.tar.gz dbus
install -m 0644 dbus.tar.gz %{buildroot}%{_datadir}/dde-daemon/
popd

%find_lang %{_name}

%pre
%service_add_pre deepin-accounts-daemon.service

%post
%service_add_post deepin-accounts-daemon.service
if [ $1 -ge 1 ]; then
  %sysusers_create deepin-daemon.conf
  %{_sbindir}/alternatives --install %{_bindir}/x-terminal-emulator \
    x-terminal-emulator %{_prefix}/lib/%{name}/default-terminal 30
fi

%preun
%service_del_preun deepin-accounts-daemon.service
if [ $1 -eq 0 ]; then
  %{_sbindir}/alternatives --remove x-terminal-emulator \
    %{_prefix}/lib/%{name}/default-terminal
fi

%postun
%service_del_postun deepin-accounts-daemon.service
if [ $1 -eq 0 ]; then
  rm -f /var/cache/deepin/mark-setup-network-services
  rm -f /var/log/deepin.log
  rm -f /usr/share/polkit-1/actions/com.deepin.daemon*
  rm -f /usr/share/dbus-1/system.d/com.deepin.daemon*
  rm -f /usr/share/dbus-1/system-services/com.deepin.daemon*
fi

%files
%defattr(-,root,root,-)
%doc README.md CHANGELOG.md
%license LICENSE
%{_bindir}/*
%exclude %{_bindir}/%{name}-dbus-installer
%exclude %{_bindir}/%{name}-polkit-installer
%dir %{_sysconfdir}/default/grub.d
%config %{_sysconfdir}/default/grub.d/10_deepin.cfg
%config %{_sysconfdir}/pam.d/deepin-auth-keyboard
%dir %{_sysconfdir}/NetworkManager
%dir %{_sysconfdir}/NetworkManager/conf.d
%config %{_sysconfdir}/NetworkManager/conf.d/deepin.dde.daemon.conf
# %{_prefix}/lib/modules-load.d/i2c_dev.conf
%dir %{_sysconfdir}/pulse/daemon.conf.d
%config %{_sysconfdir}/pulse/daemon.conf.d/10-deepin.conf
%dir %{_sysconfdir}/grub.d
%{_sysconfdir}/grub.d/35_deepin_gfxmode
%{_prefix}/lib/%{name}/
%dir %{_sysusersdir}
%{_sysusersdir}/%{name}.conf
%dir %{_prefix}/lib/systemd/logind.conf.d
%dir %{_sysconfdir}/acpi
%dir %{_sysconfdir}/acpi/actions
%dir %{_sysconfdir}/acpi/events
%{_sysconfdir}/acpi/actions/deepin_lid.sh
%config %{_sysconfdir}/acpi/events/deepin_lid
%dir %{_sysconfdir}/deepin
%config %{_sysconfdir}/deepin/grub2_edit_auth.conf
%{_prefix}/lib/systemd/logind.conf.d/10-%{name}.conf
%{_prefix}/lib/udev/rules.d/80-deepin-fprintd.rules
%{_datadir}/dbus-1/services/*.service
%dir %{_datadir}/dbus-1/system.d
%{_datadir}/%{_name}/
%exclude %{_datadir}/%{_name}/*.tar.gz
%{_datadir}/dde/
%{_datadir}/icons/hicolor/*/status/*
%dir %{_datadir}/dsg
%dir %{_datadir}/dsg/apps
%dir %{_datadir}/dsg/apps/dde-session-daemon
%dir %{_datadir}/dsg/apps/dde-session-daemon/configs
%{_datadir}/dsg/apps/dde-session-daemon/configs/gesture.json
%{_unitdir}/deepin-accounts-daemon.service
%{_sbindir}/rcdeepin-accounts-daemon
%{_sbindir}/rchwclock_stop
%dir %{_var}/lib/polkit-1
%dir %{_var}/lib/polkit-1/localauthority
%dir %{_var}/lib/polkit-1/localauthority/10-vendor.d
%{_var}/lib/polkit-1/localauthority/10-vendor.d/com.deepin.daemon.*.pkla

%files lightdm
%dir %{_sysconfdir}/lightdm/deepin
%{_sysconfdir}/lightdm/deepin/xsettingsd.conf

%files -n golang-github-linuxdeepin-deepin-daemon -f file.lst
%defattr(-,root,root,-)

%files polkit
%defattr(-,root,root,-)
%{_bindir}/%{name}-polkit-installer
%{_datadir}/%{_name}/polkit.tar.gz

%files dbus
%defattr(-,root,root,-)
%{_bindir}/%{name}-dbus-installer
%{_datadir}/%{_name}/dbus.tar.gz

%files lang -f %{_name}.lang

%changelog
* Wed Feb 23 2022 Hillwood Yang <hillwood@opensuse.org>
- Use last stable version of go to build
* Fri Feb 18 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.14.11.1
  * Add new features for network, accounts, lastore and bluetooth
  * Fix bugs
* Fri Jan 21 2022 Hillwood Yang <hillwood@opensuse.org>
- Use qdbus-qt5 instead of qdbus
- Fix login.defs path, add fix-login_defs-path.patch
* Wed Jan 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allowOBS to
  shortcut through systemd-mini.
* Thu Dec 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.13.97
  * Update translations
  * Add login reminder port
  * Fix bugs
  * New feature: global shortcut for search
- Drop harden_hwclock_stop.service.patch
* Wed Oct 27 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Leap 15.4+
* Sun Oct 24 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.13.78
  * new dependence libnss-myhostname
  * Fix bugs
* Sun Sep 19 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.13.49
  * Add xsettings config
  * Drop hwclock_stop.service
  * Fix bugs
* Fri Sep  3 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_deepin-accounts-daemon.service.patch
  * harden_hwclock_stop.service.patch
* Sat Aug 28 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix a security issue for deepin-daemon-dbus-installer and
  deepin-daemon-polkit-installer.in, change tmp dir to /root/.cache
* Sat Jul 24 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.13.36
  * Change go-dbus-factory struct as interface
  * Update test modules
  * Add SetInputIgnore ifc
  * Fix bug
- Drop xvfb-run.patch, merged by upstream
* Sat May 22 2021 Hillwood Yang <hillwood@opensuse.org>
- Keep golang version on 1.15 on Tumbleweed, the project does not support
  golang 1.16+
* Sat May  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.13.10
  * Disble bluetooth by default
  * Disble calender service
  * Fix save password on WIFI setting
  * Update call power button on dde-lock
  * Fix bluetooth connecting status
* Sun Apr 25 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Leap 15.3
* Fri Mar 12 2021 Hillwood Yang <hillwood@opensuse.org>
- Add deepin-daemon-dbus-installer and deepin-daemon-polkit-installer
* Wed Mar 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.13.6
  * Fix bugs
  * Update translations
- Add xvfb-run.patch, run `dde-pixmix` under xvfb-run
* Thu Feb 25 2021 Hillwood Yang <hillwood@opensuse.org>
- File polkit and dbus service profiles, workaround rpmlintrc errors
* Sun Feb 21 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.12.52
  * Fix bugs
  * feat: Initial packit setup
  * Update translations
  * feat(accounts): trim quotation of LOCALE`
* Thu Jul 18 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.28.0
  * Update translations
  * change(api): lid-closed-sleep distinguish whether to use battery require new
    deepin-desktop-schemas
  * fix(network): notify when password wrong
  * feat(bluetooth): add discoverable in config to control adpater discoverable
    property
  * fix: pam config deepin-auth-keyboard
  * feat(bluetooth): try connect paired devices after startup/poweron/wakeup
* Mon Jul 15 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.27.2.6
  * fix: pam config deepin-auth-keyboard
  * feat(bluetooth): try connect paired devices after startup/poweron/wakeup
  * fix(lockservice): user with a blank password authentication failure
  * fix(grub2): Theme.GetBackground return invalid file
  * fix(grub2): do not adjust theme when enable theme
  * fix(dock): menu item 'All windows' is not displayed
  * change(api): accounts User add PasswordStatus property
  * fix(dsync): Config.Destory method panic
  * chore: do not save QT_SCALE_FACTOR to ~/.dde_env
  * feat(keybinding): add reset for kwin shortcuts
  * fix(power): dde-session-daemon exit with error if failed to register
  * fix(keybinding): switch WM shortcut is easy to be triggered twice
* Tue May 21 2019 hillwood Yang <hillwood@opensuse.org>
- Update version to 3.27.2
  * feat(dock): window identify for deepin archon apps
  * chore: change polkit subject kind to system bus name
  * chore(appearance): do not set window theme during init
  * fix(appearance): do not change background after login
  * fix(audio): use unavailable sink port
  * chore(authority): add more log print
  * feat(dock): process X-Deepin-Vendor field
  * feat: add pam module deepin_auth
* Tue Apr 23 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.27.0
  * chore: auto pull translation files from transifex
  * change(api): dde-authority add method HasCookie
  * feat(dde-authority): fprint transcation give message based on user locale
  * fix(appearance): do not change background after logging in
  * fix: deepin-installer.conf
  * fix(lockservice): panic: send on closed channel
  * fix(authority): user in group nopasswdlogin auth failed
* Sun Apr 14 2019 Hillwood Yang <hillwood@opensuse.org>
- Rewrite spec with golang-packaging
  * Add disable-gobuild-in-makefile.patch
- Update version to 3.25.2
  * chore: auto pull translation files from transifex
  * chore: update depends for wm
  * feat(appearance): support set kwin window decoration theme
  * fix(greeter-setter): UpdateGreeterQtTheme rename failed
  * chore: update tranlations
  * feat(launcher): process X-Deepin-Vendor field
  * feat(dock): add method RemovePluginSettings
  * feat(dock): add method MergePluginSettings
  * feat(audio): add sync supported
  * feat(lastore): add sync supported
  * feat(appearance): add greeter background for deepin sync
  * feat(network): add sync supported
  * feat(inputdevices): add sync supported
  * feat(screenedge): add sync supported
  * feat(dock): continue to support deepin sync
  * feat(dock): support deepin sync
  * feat(appearance): support deepin sync
  * feat(launcher): support deepin sync
  * feat(dde-session-daemon): sync login sound config after all module started
  * fix(soundeffect): still play login sound even if sound effect switch is off
  * chore: auto pull translation files from transifex
  * change(api): com.deepin.daemon.Greeter add method UpdateGreeterQtTheme
  * fix: ScreenScaleFactors cannot be easily parsed by greeter
  * feat: also set the screen scale factors of the greeter
  * fix(accounts): user was not added to some groups when creating user
  * feat(grub2): keep GRUB_BACKGROUND empty if enable theme
  * feat(keybinding): add support for dde-kwin shortucts
  * chore: auto pull translation files from transifex
  * auto sync po files from transifex
  * chore: copywriting optimization
  * fix(dock): CurrentWindow prop of entry wrong after window detach
  * fix(dock): some bugs when use kwin as wm
  * change(api): appearance add methods GetScreenScaleFactors and
    SetScreenScaleFactors
  * feat: add pam-config for deepin-auth
  * feat(audo): also save the state of alsa when saving the config
  * chore(langselector): remove failed test
  * fix(audio): trySelectBestPort do not work
  * change(api): sound effect add more functions
  * change(api): add sytem service com.deepin.system.Network
  * feat(bluetooth): when disconnected quickly after connecting, automatically
    try to connect
  * chore(miracast): use go-dbus-factory
  * chore: use pkg.deepin.io/gir
  * fix(launcher) lost dbus conn when file name is invalid utf8 string
  * fix(dock): items removed when application updated
  * chore: change log level to warn
  * refactor(keybinding): extend execCmd method
  * remove usage of qdbus command
  * refactor(audio): simplify method setPort
  * fix: failed to init keyboard layout when auto login enabled
  * feat(appearance): wallpaper slideshow supported
  * feat(session/power): inhibits logind handle power key and lid switch on
    runtime
  * chore(accounts): check user greeter background validity
  * fix(network): secret agent save wrong default collection path
  * fix(dock): lost dbus conn when name of app entry is invalid utf8 string
  * chore: add network-manager-sstp to suggests
  * fix(screensaver): module start failed if x ext dpms not present
  * feat(langselector): add method GetLanguageSupportPackages for debug
  * feat: use dde-api package userenv
  * chore(accounts): get default background do not read file default.conf
  * fix(network): wired connection auto connect logic is wrong
  * chore(systeminfo): update test data
  * feat: speed up dde-session-daemon part2 startup
  * feat(dock): add property Opacity
  * fix(launcher): panic: assignment to entry in nil map
  * chore(grub2): add option -setup-theme for compatibility
  * chore: do not disconnect device when device activating
  * auto sync po files from transifex
  * feat(inputdevices): limit imwheel to only grab wheel up and down
  * feat(geature): add longpress blacklist
  * fix(clipboard): cannot copy pictures to the wine program
  * feat(soundeffect): add method GetSystemSoundFile
  * feat(power): stop screensaver before turn off screen
  * feat: rewrite clipboard module
  * refactor: replace abs coordinate with relative
  * feat(power): call CanSupsend before suspend
  * feat(grub2): gfxmode detect failed fallback to deepin-falback
  * fix(system/power): not found lid switch under the `sw_64` arch
  * fix(keybinding): GetShortcut missing Exec field for custom shortcut
  * chore: compile with sw arch no longer needs to use gccgo
  * fix(grub2): call dbus method PrepareGfxmodeDetect gfxmodes not sort
  * fix(network): the state changed signal of the active connection is not
    monitored
  * fix(dock): dock app but not saved
  * chore(trayicon): add env var for disable status notifier watcher
  * fix(appearance): panic if user object is nil
  * chore(network): change the log level of request scan error to debug
  * feat(network): can handle the change of the security type of the access
    point
  * refactor(network): fix typo
  * chore(network): remove dbus watcher
  * chore(network): remove unused code
  * chore(dock): specially stated that dde-launcher should not be displayed
  * fix(dock): call RequestDock failed
  * chore(grub2): -prepare-gfxmode-detect do not update grub cfg
  * fix: The resolution of the display has changed, but the resolution of the
    grub theme has not been adjusted in time.
  * chore(debian): modify recommends proxychains-ng to proxychains4
  * feat(session/power): screensaver supported
  * auto sync po files from transifex
  * chore(grub2): use lib imgutil
  * feat: add new module grub-gfx
  * feat(trayicon): add StatusNotifierWatcher
  * fix(launcher): failed to uninstall CrossOver
  * feat(network): add property Connectivity
  * chore(default-terminal): pass command line options directly
  * fix(network): failed to watch network manager restart
  * fix(appearance): do not fallback to default icon theme
  * feat(dock): add method GetDockedAppsDesktopFiles
  * fix: some types
  * fix: only remove batteries
  * feat(gesture): make touch long press as right button
  * fix(lastore): restore source no call UpdateSource
  * fix(dock): dde-launcher show on dock
  * fix(accounts): new user locale is empty
  * fix(network): secret agent didn't notice the requst new flag
  * network: suppress errors on tun device
  * fix(network): call ActivateAccessPoint causes dbus conn close
  * fix(network): vpn connection auto connect dose not work
  * fix(grub2): func GetAvailableResolutions is not implemented
  * fix(audio): the sound card name is too long
  * chore: remove grub-themes-deepin from suggests
  * auto sync po files from transifex
  * fix: compile errors under networkmanager 1.14+
  * refactor: fix a typo
  * feat(grub2): use adjust-grub-theme to adjust theme
  * feat(network): add new secert agent
  * fix(appearance): signal Changed type and value empty when background changed
  * fix(network): libnotify not inited
  * feat(keybinding): workaround for huawei::mic led
  * feat(appearance): do not allow to delete current backgrounds
  * fix(network): nmGetDevices nil pointer panic
  * fix(inputdevices): keyboard default layout name empty
  * fix(network): device hw address empty
  * feat(appearance): add Opacity property
  * fix: can't get the name of bluetooth speaker
  * feat(session/power): support automatically adjust brightness
  * feat(accounts): image blur check blurred image file existence
  * fix(keybinding): ShortcutManager.grabKeystroke panic
  * fix(keybinding): some data race problems
  * chore(dock): handle destroy notify event no check ev.Event
  * fix(system/power): lid switch not found
  * fix(network): correntIPv6DataType not working
  * fix(keybinding): EnableRecord panic nil pointer dereference
  * feat(dock): menu items excludes AllWindows when use 2D WM
  * fix(network): agent.cancelVpnAuthDialog panic process is nil
  * feat: add trigger to link ttc for java
  * feat(accounts): support for configuring default user background
  * feat(dock): entry add method GetAllowedCloseWindows
  * feat(dock): dbus method allow argument desktopFile is file:// url
  * fix(default-terminal): fallback if session manager failure
  * fix(audio): saveConfig panic nil pointer dereference
  * feat(keybinding): add config file handle touchpad toggle
  * fix(network): panic you should call *proxy.Object.InitSignalExt() first
  * chore: update build depends debhelper (>= 9)
  * feat(accounts): logined service add LastLogoutUser property
  * fix(x-event-monitor): no listen raw touch event
  * chore: auto sync po/ts files from transifex
  * fix(launcher):flatdeb app category wrong
  * fix(network): vpn disconnect notify name is empty
  * feat(audio): handle laptop headphones available state changed when user
    session is inactive
  * fix(dock): AppEntries.mu and Entry.PropsMu dead lock
  * chore: update call method for com.deepin.api.device
  * auto sync po files from transifex
  * fix(network): failed to watch network manager restart
  * fix(session/power): not save display brightness when power saving mode
    changed
  * refactor(network): use newly lib dbusutil
  * fix(dock): getActiveWinGroup
  * fix(mouse): handle accel profile change from gsettings
  * feat(mouse): ability to change mouse accel profile
  * chore(debian): update depends
  * chore: auto sync po files from transifex
  * chore(appearance): move set/get scale factor code to startdde
  * chore: enable lastore module
  * fix(system/power): failed to set power saving mode
  * feat(screensaver): application disconnects from the D-Bus session auto call
    uninhibit
  * feat(lastore): clean archives from UI do not send notification
  * change laptop-mode-tools to recommends
  * perf(miracast): enable daemon when needed
  * chore(debian): depends on dnsmasq-base instead of dnsmasq
  * auto sync po files from transifex
  * feat(session/power): improve english battery low messages
  * fix(network): doGuessDevice
  * fix(network): getVpnNameFile
  * auto sync po files from transifex
  * feat: add module lastore
  * auto sync po files from transifex
  * chore(x-event-monitor): use go-x11-client
  * feat: merge dde-session-daemon and dde-session-init
  * fix(apps): incorrect use of csv.Writer
  * feat(keybinding): show osd for audio-mic-mute and wlan
  * feat(power): add power saving mode
  * chore(accounts): use lib policykit1 new feature
  * chore(timedated): no use pkg.deepin.io/lib/polkit
  * chore(grub2): no use pkg.deepin.io/lib/polkit
  * chore(accounts): use go-dbus-factory
  * chore(apps): use go-dbus-factory
  * chore(timedated): use go-dbus-factory
  * chore(swapsched): use go-dbus-factory
  * chore(langselector): refactor code
  * chore(system-daemon): remove unused func requestUnblockAllDevice
  * chore(langselector): use go-dbus-factory
  * chore(appearance): use go-dbus-factory
  * chore(bluetooth): use go-dbus-factory
  * chore(launcher): use go-dbus-factory
  * chore(inputdevices): use go-x11-client
  * chore(dock): use go-dbus-factory
  * chore(default-terminal): use go-dbus-factory
  * chore: do not beep if dde-session-init request name failed
  * perf: optimize key2Mod
  * chore(session/power): use go-x11-client
  * fix: x resource id not freed
  * chore: update for go-x11-client
  * perf(apps): do not loop check subrecorder root ok
  * feat(x_event_monitor): add debug method DebugGetPidAreasMap
  * chore(screensaver): use go-x11-client
  * fix(x_event_monitor): test build failed
  * chore(x_event_monitor): remove debug for handleKeyboardEvent
  * chore(x_event_monitor): use lib go-x11-client
  * fix(audio): some data race problems
  * chore: update for go-x11-client
  * chore(dock): use lib go-x11-client
  * fix(launcher): no app found in launcher
  * auto sync po files from transifex
  * fix(apps) dead lock again
  * chore(accounts): users in the nopasswdlogin group are treated as human users
  * fix(apps): dead lock
  * chore(appearance): do not list pictures in dir /usr/share/backgrounds
  * feat(inputdevices): layout only saved in accounts user
  * fix(network/proxychains): failed to remove conf if type0 is empty
  * fix(session-daemon): some data race problems
  * feat(appearance): sync desktop backgrounds during startup
  * fix(dock): panic if winInfo.wmClass is nil
  * chore(dock): entry.attachWindow print window info
  * chore: update makefile
  * chore: update makefile for arch `sw_64`
  * fix(gesture): disabled if session inactive
  * add fprintd depends in `Desktop edition system`
  * fix(network): allow to delete when creating vpn connection
  * chore(debian): update build-depends
  * feat(apps): record the launched state of the removed app
  * auto sync po files from transifex
  * feat(appearances): set standard font as monospace font fallback
  * fix(appearance): cursor size of window border is small
  * chore(housekeeping): use go-dbus-factory
  * fix(bluetooth): remove adapters and devices config
  * chore(launcher): move launcher module to dde-session-daemon
  * fix(bluetooth): adapter powered not saved
  * auto sync po files from transifex
  * refactor(bluetooth): refactor code again
  * refactor(bluetooth): refactor code
  * feat(bluetooth): add signal Cancelled
  * chore(bluetooth): use go-dbus-factory
  * chore(appearance): use go-dbus-factory
  * chore(audio): use go-dbus-factory
  * chore(fprintd) use go-dbus-factory
  * chore(systeminfo): use go-dbus-factory
  * chore(timedate): use go-dbus-factory
  * chore(gesture): use go-dbus-factory
  * chore(screenedge): use go-dbus-factory
  * chore(keybinding): use go-dbus-factory
  * fix(apps): directory permissions is not 0755
  * chore(sessionwatcher): use go-dbus-factory
  * chore(session/power): use go-dbus-factory
  * feat: add UI unified authentication service
  * fix(session/power): submodule name typo
  * fix(session/power): submodule name typo
  * fix(network): close hotspot no send notification
  * feat(default-terminal): remove --launch-app option
  * feat(network): ConnectionSession add method SetKeyFd
  * feat(keybinding): allow volume to be adjusted to maximum 150%%
  * feat: add apps.com.wechat.web to window_patterns
  * feat(appearance): limit the number of custom wallpapers
  * fix(miracast): failed to emit signal Added and Removed
* Thu Apr 12 2018 hillwood@opensuse.org
- Update version to 3.2.13.
  * chore(dock): add window pattern for gdevelop
  * fix(appearance): add rgba seetings for wine
  * auto sync po files from transifex
  * feat(dock): add window identify for org.deepin.flatdeb.*
  * refactor: improve english
  * refactor(miracast): use newly lib dbusutil
  * fix(session-daemon): different modules startup sequence
  * auto sync po files from transifex
  * fix(audio): nil pointer error in handleCardEvent
  * refactor(session-daemon): use newly lib dbusutil
  * refactor(bluetooth): use newly lib dbusutil
  * fix(accounts): get blurred image without compare change time
  * refactor(fprintd): use newly lib dbusutil
  * refactor(audio): use newly lib dbusutil
  * refactor(inputdevices): use newly lib dbusutil
  * refactor(appearance): use newly lib dbusutil
  * fix(network): allow to delete when creating connection
  * fix(network): fix device mac address unchanged after set it to empty
  * refactor(keybinding): use newly lib dbusutil
  * fix(network): filter notify if device disabled
  * refactor(mime): use newly lib dbusutil
  * refactor(timedate): use newly lib dbusutil
  * refactor(screenedge): use newly lib dbusutil
  * refactor(sessionwatcher): use newly lib dbusutil
  * refactor(systeminfo): use newly lib dbusutil
  * refactor(screensaver): use newly lib dbusutil
  * refactor(session/power): use lib dbusutil
  * chore: use lib dbusutil new api
  * auto sync po files from transifex
  * refactor(dock): optimize design
  * fix(accounts): replace plaintext with ciphertext when set passwd
  * fix(system-daemon): missing the method ScalePlymouth
  * chore: only enable systemd service
  * fix(lockservice): fix event crash after the frequent unlocking
  * feat(session-init): use newly lib dbusutil
  * refactor: remove dbusutil.PropsMaster
  * feat(network): add l2tp ipsec ike/esp settings
  * Revert "feat(session/power): set dpms off before suspend"
  * auto sync po files from transifex
  * fix(network): fix add connection failed if no activated
  * fix(network): correct wired ip unavailable notification
  * feat: make calltrace as module
  * feat(system-daemon): use newly lib dbusutil
  * fix(default-terminal): can not handle the -e option
  * feat(langselector): replace PropsMu with PropsMaster
  * feat(grub2): replace PropsMu with PropsMaster
  * fix(timedate): fix polkit message untranslated
  * fix: optimize channel statements
  * feat(swapsched): add blkio controller
  * feat(dock): window flash supported
  * refactor(debug): watch cpu/mem anormaly
  * fix(soundeffect): property name Enabled typo
  * feat(soundeffect): use newly lib dbusutil
  * feat(search): use newly lib dbusutil
  * feat(langselector): use newly lib dbusutil
  * feat(grub2): use newly lib dbusutil
  * feat(dde-lockservice): use newly lib dbusutil
  * feat(dde-greeter-setter): use newly lib dbusutil
  * feat(`backlight_helper`): use newly lib dbusutil
  * feat: add calltrace to dump runtime stack
  * chore(translations): update translation source
  * chore(accounts): correct policy translations
  * chore: correct network translations
  * chore: update license
  * chore: add accounts systemd service file
  * chore: move bluez and fprintd to optional dependencies
  * feat(trayicon): merge damage notify events
  * fix(session/power): method StartupNotify appears in the DBus interface
  * fix(accounts): change user config path
  * feat: use new lib gsettings
  * feat(keybinding): regrabAll only after keyboard layout changed
  * fix(dock): dock not show if launcher shown
  * fix: optimize appearance gsettings signal
  * refactor(accounts): elaborate login related action
  * feat(accounts): improve user auth action
  * fix: terminal opened by dde-file-manager work dir is wrong
  * feat: use tool deepin-policy-ts-convert to handle the
  * docs: `add service_trigger.md`
  * feat: dde-session-daemon add new module `service_trigger`
* Fri Mar  2 2018 hillwood@opensuse.org
- Update version to 3.2.9
  * Add some moudles
  * Features update
  * Fix bugs
* Tue Dec  5 2017 hillwood@opensuse.org
- Don't change openSUSE default grub2 theme.
* Thu Nov 30 2017 hillwood@opensuse.org
- Update to 3.2.7
  * gesture: check keyboard grab status before do action
  * mime: add multi default app id
  * audio: select best port if config non-exist
  * plymouth: support ssd theme checker
  * dock: fix index in signal EntryAdded is wrong
  * add flatpak to recommends
  * audio: remove style in font config
  * network: fix wireless disconnect when delete inactive hotspot
  * logined: update 'UserList' when session removed
  * network: remove autoconnect from wireless hotspot
  * appearance: fix fonts memory used large when loading
  * audio: add switcher to decide whether auto switch port
  * add com.deepin.daemon.ImageBlur interface
  * not show newly installed wechat in launcher
  * failed to set some bmp image file as icon
  * the Accels field of two shortcuts is empty
  * make `install_to_hicolor.py` compatibility with older python3
  * automatic switch port when card changed
  * add shortcut for deepin-system-monitor and color-picker
  * support deepin qt theme settings
  * add touchpad tap gesture
  * add flatpak app window identify method
  * fix gccgo compile failed
  * fix syndaemon pid file not created
  * fix wireless not work after multiple toggle hotspot
  * fix active connections not updated when deleted the last connection
  * update font config xml version
  * refactor grub theme dbus interface
  * rename 'Logout' shortcut to 'Shutdown Interface'
  * add dependency 'dnsmasq'
  * update notifications for scale setting
  * keybinding:  process grab pointer failed ([328aa07a](328aa07a))
  * add fprintd module ([1469e2d4](1469e2d4))
  * fix fprint dependencies missing ([22dc0735](22dc0735))
  * langselector:  write the configuration file wrong ([ee018ea2](ee018ea2))
  * network: remove band settings from hotspot
  * add proxychains-ng as suggested dependency
  * launcher: RequestUninstall does not remove desktop file in autostart directory
    ([24d1b698](24d1b698))
  * grub2 policykit message not using user's locale ([aa461794](aa461794))
  * keybinding: failed to handle GSettings changed event correctly
  ([7583b35b](7583b35b))
  * network: delete dot at end ([800eb0c4](800eb0c4))
  * appearance: Fix scale set failed if file not found ([61b72897](61b72897))
  * keybinding can not use key Delete to delete keystroke ([deae5285](deae5285))
  * support setting plymouth scale ([842a080e](842a080e))
  * add fprintd module ([1469e2d4](1469e2d4))
  * keybinding: AddCustomShortcut returns id and type of newly created shortcut
  ([d74f34f8](d74f34f8))
  * accounts: Add no password login ([b87c7448](b87c7448))
  * keybinding: update screenshot command ([64f62269](64f62269))
  * appearance: theme thumbnail support display scaling ([7cba49d6](7cba49d6))
  * dock: menu of entry add item "Force Quit" ([7b853187](7b853187))
  * appearance: Update greeter config when setting scale ([f1b37a80](f1b37a80))
  * network: Implement routes methods ([6889c2d3](6889c2d3))
  * Add 'dde-greeter-setter' ([4dd38e68](4dd38e68))
  * iw: replace 'iw' command with libnl
- Add deepin-daemon-libinput.patch. Fix build on libinput.
* Wed Nov 15 2017 hillwood@opensuse.org
- Cleanup spec
- Split language package.
* Tue Oct  3 2017 sensor.wen@gmail.com
  Initial package.
